## MeDIL
MeDIL is a Python package for causal factor analysis, using the measurement dependence inducing latent (MeDIL) causal model framework[<sup>1</sup>](#medil_paper).
In addition to simple linear Gaussian models, MeDIL also supports deep generative models[<sup>2</sup>](#ncfa_paper).

More information can be found in the [documentation](https://medil.causal.dev).

### Support, Bugs, and Contributing
If you have any questions, suggestions, feedback, or bugs to report, please [open an issue on Gitlab](https://gitlab.com/alex-markham/medil/issues/new) or [on Github](https://github.com/Alex-Markham/medil/issues/new) or [contact me](https://causal.dev/#contact).

Thanks to contributors An Hui Chang, [Aditya Chivukula](https://github.com/adityachivu/), and [Mingyu Liu](https://github.com/JerryLiuMY)!

### License
See [LICENSE](https://gitlab.com/alex-markham/medil/blob/master/LICENSE.md), which is the GNU Affero General Public License version 3 or later (AGPLv3+).

### Changelog
See [CHANGELOG](https://gitlab.com/alex-markham/medil/blob/master/CHANGELOG.md) for a history of the already implemented features, works in progress, and future feature ideas.

### References
<a name="medil_paper"> 1.</a> Alex Markham & Moritz Grosse-Wentrup (2020). Measurement Dependence Inducing Latent Causal Models. In *Conference on Uncertainty in Artificial Intelligence (UAI)* PMLR 124:590&ndash;599. URL: [http://proceedings.mlr.press/v124/markham20a/markham20a.pdf](http://proceedings.mlr.press/v124/markham20a/markham20a.pdf).

<a name="ncfa_paper"> 2.</a> Alex Markham, Mingyu Liu, Bryon Aragam, Liam Solus (2023). Neuro-Causal Factor Analysis. *prepint*. [arXiv:2305.19802](https://arxiv.org/abs/2305.19802) [stat.ML].
